(function (exports) {
'use strict';

/* global performance */

var now;

{
  if (typeof performance !== 'undefined' && performance.now) {
    now = function () { return performance.now(); };
  } else {
    now = function () { return Date.now(); };
  }
}

var now$1 = now;

/* global performance */

var supportsMarkMeasure = typeof performance !== 'undefined' && performance.mark && performance.measure;

// simple binary sort insertion
function insertSorted (arr, item, comparator) {
  var low = 0;
  var high = arr.length;
  var mid;
  while (low < high) {
    mid = (low + high) >>> 1;
    if (comparator(arr[mid]) < comparator(item)) {
      low = mid + 1;
    } else {
      high = mid;
    }
  }
  arr.splice(low, 0, item);
}

/* global performance */

function throwIfEmpty (name) {
  if (!name) {
    throw new Error('name must be non-empty')
  }
}

if (supportsMarkMeasure) {
  exports.mark = function (name) {
    throwIfEmpty(name);
    performance.mark(("start " + name));
  };
  exports.stop = function (name) {
    throwIfEmpty(name);
    performance.mark(("end " + name));
    performance.measure(name, ("start " + name), ("end " + name));
    var entries = performance.getEntriesByName(name);
    return entries[entries.length - 1]
  };
  exports.getEntries = function () { return performance.getEntriesByType('measure'); };
} else {
  var marks = {};
  var entries = [];
  exports.mark = function (name) {
    var startTime = now$1();
    throwIfEmpty(name);
    marks['$' + name] = startTime;
  };
  exports.stop = function (name) {
    var endTime = now$1();
    throwIfEmpty(name);
    var startTime = marks['$' + name];
    if (!startTime) {
      throw new Error(("no known mark: " + name))
    }
    var entry = {
      startTime: startTime,
      name: name,
      duration: endTime - startTime,
      entryType: 'measure'
    };
    // per the spec this should be at least 150:
    // https://www.w3.org/TR/resource-timing-1/#extensions-performance-interface
    // we just have no limit, per Chrome and Edge's de-facto behavior
    insertSorted(entries, entry, function (x) { return x.startTime; });
    return entry
  };
  exports.getEntries = function () { return entries; };
}

}((this.marky = this.marky || {})));
