/* global performance */

var now;

{
  // implementation borrowed from:
  // https://github.com/myrne/performance-now/blob/6223a0d544bae1d5578dd7431f78b4ec7d65b15c/src/performance-now.coffee
  var hrtime = process.hrtime;
  var getNanoSeconds = function () {
    var hr = hrtime();
    return hr[0] * 1e9 + hr[1]
  };
  var loadTime = getNanoSeconds();
  now = function () { return ((getNanoSeconds() - loadTime) / 1e6); };
}

var now$1 = now;

/* global performance */

var supportsMarkMeasure = typeof performance !== 'undefined' && performance.mark && performance.measure;

// simple binary sort insertion
function insertSorted (arr, item, comparator) {
  var low = 0;
  var high = arr.length;
  var mid;
  while (low < high) {
    mid = (low + high) >>> 1;
    if (comparator(arr[mid]) < comparator(item)) {
      low = mid + 1;
    } else {
      high = mid;
    }
  }
  arr.splice(low, 0, item);
}

/* global performance */

function throwIfEmpty (name) {
  if (!name) {
    throw new Error('name must be non-empty')
  }
}

var mark;
var stop;
var getEntries;

if (supportsMarkMeasure) {
  mark = function (name) {
    throwIfEmpty(name);
    performance.mark(("start " + name));
  };
  stop = function (name) {
    throwIfEmpty(name);
    performance.mark(("end " + name));
    performance.measure(name, ("start " + name), ("end " + name));
    var entries = performance.getEntriesByName(name);
    return entries[entries.length - 1]
  };
  getEntries = function () { return performance.getEntriesByType('measure'); };
} else {
  var marks = {};
  var entries = [];
  mark = function (name) {
    var startTime = now$1();
    throwIfEmpty(name);
    marks['$' + name] = startTime;
  };
  stop = function (name) {
    var endTime = now$1();
    throwIfEmpty(name);
    var startTime = marks['$' + name];
    if (!startTime) {
      throw new Error(("no known mark: " + name))
    }
    var entry = {
      startTime: startTime,
      name: name,
      duration: endTime - startTime,
      entryType: 'measure'
    };
    // per the spec this should be at least 150:
    // https://www.w3.org/TR/resource-timing-1/#extensions-performance-interface
    // we just have no limit, per Chrome and Edge's de-facto behavior
    insertSorted(entries, entry, function (x) { return x.startTime; });
    return entry
  };
  getEntries = function () { return entries; };
}

export { mark, stop, getEntries };
